@@ -13,7 +13,7 @@ Copyright (C) 2000 Andy Piper. */
 #define XEMACS_DEFAULT_ROOT "\\Meadow"
 #define XEMACS_CYGWIN_DEFAULT_ROOT "\\usr\\local"
 
-#define XEMACS_SETUP_DIR "\\setup\\"
+#define XEMACS_SETUP_DIR "\\packages\\setup\\"
 #define XEMACS_RESOURCE_DIR "\\"
 #define XEMACS_PACKAGE_DIR "\\"
 #define XEMACS_NATIVE_ARCH_NAME "i586-pc-win32"
